@@ -1,5 +1,5 @@
 from bolinette.core import functions
 from bolinette.core.models import Model, ModelMetadata, ModelProperty
-from bolinette.core.mixin import Mixin
+from bolinette.core.mixin import Mixin, MixinServiceMethod
 from bolinette.core.repository import Repository
-from bolinette.core.service import Service, ServiceMetadata, SimpleService, HistorizedService
+from bolinette.core.service import Service, ServiceMetadata, SimpleService
