@@ -40,4 +40,9 @@ def rm(path):
 
 
 def rm_r(path):
+    for root, dirs, files in os.walk(path, topdown=False):
+        for name in files:
+            os.remove(os.path.join(root, name))
+        for name in dirs:
+            os.rmdir(os.path.join(root, name))
     os.rmdir(path)
